/*********************************************************************
 * Copyright (c) 2021 Boeing
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Boeing - initial API and implementation
 **********************************************************************/
package org.eclipse.osee.mim;

import java.util.Collection;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import org.eclipse.osee.framework.core.data.ArtifactId;
import org.eclipse.osee.mim.types.InterfaceStructureToken;

/**
 * @author Luciano T. Vaglienti
 */
@Path("structures")
public interface InterfaceStructureEndpoint {

   @GET()
   @Produces(MediaType.APPLICATION_JSON)
   /**
    * Gets structure for a given sub message
    *
    * @return all structures for a given sub message
    */
   Collection<InterfaceStructureToken> getAllStructures();

   @GET()
   @Path("{id}")
   @Produces(MediaType.APPLICATION_JSON)
   /**
    * Gets a specific structure of a given sub message
    *
    * @param structureId id of structure to fetch
    * @return structure that is fetched
    */
   InterfaceStructureToken getStructure(@PathParam("id") ArtifactId structureId);

   @GET()
   @Path("{id}/{filter}")
   @Produces(MediaType.APPLICATION_JSON)
   /**
    * Gets a specific structure of a given sub message
    *
    * @param structureId id of structure to fetch
    * @return structure that is fetched
    */
   InterfaceStructureToken getStructureAndFilterElements(@PathParam("id") ArtifactId structureId, @PathParam("filter") String filter);
}
